# FundingContributorV30

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**contributor_orcid** | [**ContributorOrcidV30**](ContributorOrcidV30.md) |  | [optional] 
**credit_name** | [**CreditNameV30**](CreditNameV30.md) |  | [optional] 
**contributor_email** | [**ContributorEmailV30**](ContributorEmailV30.md) |  | [optional] 
**contributor_attributes** | [**FundingContributorAttributesV30**](FundingContributorAttributesV30.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

